# This file was auto-generated by Fern from our API Definition.

import typing
from .environment import NewscatcherApiEnvironment
import httpx
from .core.client_wrapper import SyncClientWrapper
from .search.client import SearchClient
from .latestheadlines.client import LatestheadlinesClient
from .authors.client import AuthorsClient
from .search_link.client import SearchLinkClient
from .searchsimilar.client import SearchsimilarClient
from .sources.client import SourcesClient
from .aggregation.client import AggregationClient
from .subscription.client import SubscriptionClient
from .core.client_wrapper import AsyncClientWrapper
from .search.client import AsyncSearchClient
from .latestheadlines.client import AsyncLatestheadlinesClient
from .authors.client import AsyncAuthorsClient
from .search_link.client import AsyncSearchLinkClient
from .searchsimilar.client import AsyncSearchsimilarClient
from .sources.client import AsyncSourcesClient
from .aggregation.client import AsyncAggregationClient
from .subscription.client import AsyncSubscriptionClient


class BaseNewscatcherApi:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : NewscatcherApiEnvironment
        The environment to use for requests from the client. from .environment import NewscatcherApiEnvironment



        Defaults to NewscatcherApiEnvironment.DEFAULT



    api_key : str
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from newscatcher import NewscatcherApi

    client = NewscatcherApi(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: NewscatcherApiEnvironment = NewscatcherApiEnvironment.DEFAULT,
        api_key: str,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.search = SearchClient(client_wrapper=self._client_wrapper)
        self.latestheadlines = LatestheadlinesClient(client_wrapper=self._client_wrapper)
        self.authors = AuthorsClient(client_wrapper=self._client_wrapper)
        self.search_link = SearchLinkClient(client_wrapper=self._client_wrapper)
        self.searchsimilar = SearchsimilarClient(client_wrapper=self._client_wrapper)
        self.sources = SourcesClient(client_wrapper=self._client_wrapper)
        self.aggregation = AggregationClient(client_wrapper=self._client_wrapper)
        self.subscription = SubscriptionClient(client_wrapper=self._client_wrapper)


class AsyncBaseNewscatcherApi:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : NewscatcherApiEnvironment
        The environment to use for requests from the client. from .environment import NewscatcherApiEnvironment



        Defaults to NewscatcherApiEnvironment.DEFAULT



    api_key : str
    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from newscatcher import AsyncNewscatcherApi

    client = AsyncNewscatcherApi(
        api_key="YOUR_API_KEY",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: NewscatcherApiEnvironment = NewscatcherApiEnvironment.DEFAULT,
        api_key: str,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = timeout if timeout is not None else 60 if httpx_client is None else None
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self.search = AsyncSearchClient(client_wrapper=self._client_wrapper)
        self.latestheadlines = AsyncLatestheadlinesClient(client_wrapper=self._client_wrapper)
        self.authors = AsyncAuthorsClient(client_wrapper=self._client_wrapper)
        self.search_link = AsyncSearchLinkClient(client_wrapper=self._client_wrapper)
        self.searchsimilar = AsyncSearchsimilarClient(client_wrapper=self._client_wrapper)
        self.sources = AsyncSourcesClient(client_wrapper=self._client_wrapper)
        self.aggregation = AsyncAggregationClient(client_wrapper=self._client_wrapper)
        self.subscription = AsyncSubscriptionClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: NewscatcherApiEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")
